summaryrefslogtreecommitdiff
path: root/src/commands.h
diff options
context:
space:
mode:
authorJim Blandy <jimb@redhat.com>1993-01-26 01:58:16 +0000
committerJim Blandy <jimb@redhat.com>1993-01-26 01:58:16 +0000
commitdbc4e1c12940079cad7b24e1654a0badcda8d6fc (patch)
treee0fbea5b15bd13d2839c8b59b624cec80f31bfd8 /src/commands.h
parent72766144811cd7258b2a59e56f6e3657537ea508 (diff)
downloademacs-dbc4e1c12940079cad7b24e1654a0badcda8d6fc.tar.gz
emacs-dbc4e1c12940079cad7b24e1654a0badcda8d6fc.tar.bz2
emacs-dbc4e1c12940079cad7b24e1654a0badcda8d6fc.zip
JimB's changes since January 18th
Diffstat (limited to 'src/commands.h')
-rw-r--r--src/commands.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/commands.h b/src/commands.h
index 4e3d67d166e..4abdcac56f1 100644
--- a/src/commands.h
+++ b/src/commands.h
@@ -49,12 +49,12 @@ extern Lisp_Object last_command_char;
reached by the mouse. */
extern Lisp_Object last_nonmenu_event;
-/* Command event to be re-read, or Qnil. */
-extern Lisp_Object unread_command_event;
+/* List of command events to be re-read, or Qnil. */
+extern Lisp_Object unread_command_events;
/* If not Qnil, this is a switch-frame event which we decided to put
off until the end of a key sequence. This should be read as the
- next command input, after any unread_command_event.
+ next command input, after any unread_command_events.
read_key_sequence uses this to delay switch-frame events until the
end of the key sequence; Fread_char uses it to put off switch-frame